@@ -14,9 +14,11 @@ import cv2
 environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 stderr = sys.stderr
 sys.stderr = open(devnull, 'w')
-from keras.models import load_model
-sys.stderr = stderr
 import tensorflow as tf
+from tensorflow.keras.models import load_model
+from tensorflow.python.keras import backend as tensorflow_backend
+sys.stderr = stderr
+
 
 import logging
 
@@ -38,12 +40,14 @@ class SbbBinarizer:
             self.models.append(self.load_model(model_file))
 
     def start_new_session(self):
-        config = tf.ConfigProto()
+        config = tf.compat.v1.ConfigProto()
         config.gpu_options.allow_growth = True
 
-        self.session = tf.Session(config=config)  # tf.InteractiveSession()
+        self.session = tf.compat.v1.Session(config=config)  # tf.InteractiveSession()
+        tensorflow_backend.set_session(self.session)
 
     def end_session(self):
+        tensorflow_backend.clear_session()
         self.session.close()
         del self.session
 
@@ -55,6 +59,7 @@ class SbbBinarizer:
         return model, model_height, model_width, n_classes
 
     def predict(self, model_in, img, use_patches):
+        tensorflow_backend.set_session(self.session)
         model, model_height, model_width, n_classes = model_in
         
         img_org_h = img.shape[0]
